@@ -25,7 +25,7 @@ THE SOFTWARE.
 
 import sys
 
-VERSION = (0, 6, 5)
+VERSION = (0, 6, 6)
 
 try:
     from cymysql import convertersx as converters
@@ -78,7 +78,7 @@ ROWID     = DBAPISet()
 
 def Binary(x):
     """Return x as a binary type."""
-    return str(x)
+    return bytes(x)
 
 def Connect(*args, **kwargs):
     """
